@@ -15,7 +15,7 @@
 #include <QtGui/QPainter>
 #include <QtOpenGL/QOpenGLFramebufferObject>
 #include <QtGui/QOffscreenSurface>
-#if defined(Q_OS_OSX)
+#if defined(Q_OS_MACOS)
 #include <qpa/qplatformnativeinterface.h>
 #endif
 
@@ -200,11 +200,12 @@ QAbstract3DGraph::QAbstract3DGraph(QAbstract3DGraphPrivate *d, const QSurfaceFor
 
     d_ptr->renderLater();
 
-#if defined(Q_OS_OSX)
+#if defined(Q_OS_MACOS)
     // Enable touch events for Mac touchpads
     typedef void * (*EnableTouch)(QWindow*, bool);
-    EnableTouch enableTouch =
-            (EnableTouch)QGuiApplication::platformNativeInterface()->nativeResourceFunctionForIntegration("registertouchwindow");
+    EnableTouch enableTouch = reinterpret_cast<EnableTouch>(
+            QFunctionPointer(QGuiApplication::platformNativeInterface()
+                                     ->nativeResourceFunctionForIntegration("registertouchwindow")));
     if (enableTouch)
         enableTouch(this, true);
 #endif
@@ -567,7 +568,7 @@ QCustom3DItem *QAbstract3DGraph::selectedCustomItem() const
  * \c selectedElementChanged signal is emitted.
  *
  * The signal can be used for example for implementing custom input handlers, as
- * demonstrated by the \l {Axis Range Dragging With Labels Example}.
+ * demonstrated in the \l {Graph Gallery} example under \uicontrol {Scatter Graph} tab.
  *
  * \sa selectedLabelIndex(), selectedAxis(), selectedCustomItemIndex(), selectedCustomItem(),
  * Q3DBars::selectedSeries(), Q3DScatter::selectedSeries(), Q3DSurface::selectedSeries(),
@@ -1040,8 +1041,10 @@ QAbstract3DGraphPrivate::~QAbstract3DGraphPrivate()
         m_offscreenSurface->destroy();
         delete m_offscreenSurface;
     }
-    if (m_context)
-        m_context->makeCurrent(q_ptr);
+    if (m_context) {
+        if (!m_context->makeCurrent(q_ptr))
+            m_context->doneCurrent();
+    }
 
     delete m_visualController;
 }
