@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Data Visualization module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include "volumetrictest.h"
 #include <QtDataVisualization/qbar3dseries.h>
@@ -38,6 +12,9 @@
 #include <QtGui/QRgb>
 #include <QtGui/QImage>
 #include <QtWidgets/QLabel>
+
+#include <QtGui/qquaternion.h>
+
 #include <QtCore/QDebug>
 
 const int imageCount = 512;
@@ -281,15 +258,15 @@ void VolumetricModifier::testSubtextureSetting()
 
     // Do some visible swaps on volume 3
     QImage slice = m_volumeItem3->renderSlice(Qt::XAxis, 144);
-    slice = slice.mirrored();
+    slice.flip();
     m_volumeItem3->setSubTextureData(Qt::XAxis, 144, slice);
 
     slice = m_volumeItem3->renderSlice(Qt::YAxis, 80);
-    slice = slice.mirrored();
+    slice.flip();
     m_volumeItem3->setSubTextureData(Qt::YAxis, 80, slice);
 
     slice = m_volumeItem3->renderSlice(Qt::ZAxis, 190);
-    slice = slice.mirrored(true, false);
+    slice.flip(Qt::Horizontal);
     m_volumeItem3->setSubTextureData(Qt::ZAxis, 190, slice);
 }
 
@@ -430,7 +407,7 @@ void VolumetricModifier::createVolume()
     uchar *p = data;
 
     // Change one picture using subtexture replacement
-    QImage flipped = logo.mirrored();
+    QImage flipped = logo.flipped();
     m_volumeItem->setSubTextureData(Qt::ZAxis, 100, flipped);
 
     // Clean up the two extra pixels
@@ -562,7 +539,7 @@ void VolumetricModifier::createAnotherVolume()
                                        zRange * 2.0f));
 
     // Change one picture using subtexture replacement
-    QImage flipped = logo.mirrored();
+    QImage flipped = logo.flipped();
     m_volumeItem2->setSubTextureData(Qt::ZAxis, 100, flipped);
     //m_volumeItem2->setAlphaMultiplier(0.2f);
     m_volumeItem2->setPreserveOpacity(false);
